fix-engine.blotter.messaging


->trade-messaging-fixclj

(->trade-messaging-fix account
                       asset-converter
                       log
                       cancel-req-atom
                       modify-req-atom)

Positional factory function for class fix_engine.blotter.messaging.trade-messaging-fix.

Positional factory function for class fix_engine.blotter.messaging.trade-messaging-fix.
raw docstring

blotter-order->fix-payloadclj

(blotter-order->fix-payload order asset-converter)
(blotter-order->fix-payload order
                            asset-converter
                            cancel-req-atom
                            modify-req-atom)

Blotter trader order -> fix-translator [msg-type payload]. Optional cancel-req-atom / modify-req-atom store client request ids (FIX ClOrdID) mapped to blotter order-ids for inbound reject correlation.

Blotter trader order -> fix-translator [msg-type payload].
Optional `cancel-req-atom` / `modify-req-atom` store client request ids
(FIX ClOrdID) mapped to blotter order-ids for inbound reject correlation.
raw docstring

fix-payload->blotter-updateclj

(fix-payload->blotter-update account-id asset-converter msg)
(fix-payload->blotter-update account-id
                             asset-converter
                             cancel-req-atom
                             modify-req-atom
                             [msg-type payload])

fix-translator [msg-type payload] -> blotter broker message or nil.

fix-translator [msg-type payload] -> blotter broker message or nil.
raw docstring

map->trade-messaging-fixclj

(map->trade-messaging-fix m__7972__auto__)

Factory function for class fix_engine.blotter.messaging.trade-messaging-fix, taking a map of keywords to field values.

Factory function for class fix_engine.blotter.messaging.trade-messaging-fix, taking a map of keywords to field values.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries