(configured-accounts fix-engine)(create-fix-engine fix-config-file)creates a fix-engine instance
creates a fix-engine instance
(get-quote-session fix-engine account-kw)(get-session fix-engine account-kw interactor)gets a session for an account this is the fix-engine state (use create-fix-engine)
gets a session for an account this is the fix-engine state (use create-fix-engine)
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |