Clojure only.

fix-engine.impl.log-flow


flow-senderclj

(flow-sender)

Returns {:flow f :send s} where (s v) publishes v on f.

Returns {:flow f :send s} where (s v) publishes v on f.
raw docstring

msg-flowclj

(msg-flow !-a)

Missionary flow backed by a single downstream subscription (see flow-sender).

Missionary flow backed by a single downstream subscription (see flow-sender).
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries