(connected? stream)(create-client this)(create-msg-writer this stream)(create-read-f this stream)(deferred->task df)Returns a missionary task completing with the result of given manifold-deferred.
Returns a missionary task completing with the result of given manifold-deferred.
(encode-fix-msg-log this fix-type-payload-vec)(encode-fix-msg-no-log this fix-type-payload-vec)(read-msg-t this stream)(wrap-duplex-stream s)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |