fix-engine.quote.messaging


->quote-feed-fixclj

(->quote-feed-fix account-config asset-converter log)

Positional factory function for class fix_engine.quote.messaging.quote-feed-fix.

Positional factory function for class fix_engine.quote.messaging.quote-feed-fix.
raw docstring

map->quote-feed-fixclj

(map->quote-feed-fix m__7972__auto__)

Factory function for class fix_engine.quote.messaging.quote-feed-fix, taking a map of keywords to field values.

Factory function for class fix_engine.quote.messaging.quote-feed-fix, taking a map of keywords to field values.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries