quanta.blotter.protocol2


create-trade-messagingcljmultimethod

a tradeaccount must implement this method to create it. each quotefeed implementation must have a unique :type. A quotefeed must implement subscription-topic protocol.

a tradeaccount must implement this method to create it.
each quotefeed implementation must have a unique :type.
  A quotefeed must implement subscription-topic protocol.
raw docstring

trade-messagingcljprotocol

api-orderclj

(api-order this normalized-order-msg-in)

blotter-order-updateclj

(blotter-order-update this broker-orderupdate-msg-in)

cljdoc builds & hosts documentation for Clojure/Script libraries