quanta.quote.protocol


create-quote-accountcljmultimethod

a trade-account must implement this method to create it. account-config is a map that must contain :account/id - unique identifier (long) :account/api - the quote api identifier (keyword) :account/settings - settings as required by the api subscription-a - a set of asset ids that the account is subscribed to emit-quote - a function that can send quotes to the account log - a function that can log messages

a trade-account must implement this method to create it.
account-config is a map that must contain 
   :account/id  - unique identifier (long)
   :account/api - the quote api identifier (keyword)
   :account/settings - settings as required by the api
subscription-a - a set of asset ids that the account is subscribed to
emit-quote - a function that can send quotes to the account
log - a function that can log messages
raw docstring

create-quote-messagingcljmultimethod

a tradeaccount must implement this method to create it. each quotefeed implementation must have a unique :type. A quotefeed must implement subscription-topic protocol.

a tradeaccount must implement this method to create it.
each quotefeed implementation must have a unique :type.
  A quotefeed must implement subscription-topic protocol.
raw docstring

quote-messagingcljprotocol

read-quoteclj

(read-quote this msg-in)

subscribe-msgclj

(subscribe-msg this sub)

unsubscribe-msgclj

(unsubscribe-msg this unsub)

cljdoc builds & hosts documentation for Clojure/Script libraries