a tradeaccount must implement this method to create it. each quotefeed implementation must have a unique :type. A quotefeed must implement subscription-topic protocol.
a tradeaccount must implement this method to create it. each quotefeed implementation must have a unique :type. A quotefeed must implement subscription-topic protocol.
(api-order this normalized-order-msg-in)(blotter-order-update this broker-orderupdate-msg-in)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |